# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import warehouse_delivery_method_pb2 as v1_dot_rules_dot_warehouse__delivery__method__pb2


class WarehouseDeliveryMethodServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.WarehouseDeliveryMethodCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodService/WarehouseDeliveryMethodCreate",
            request_serializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodCreateResponse.FromString,
        )
        self.WarehouseDeliveryMethodRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodService/WarehouseDeliveryMethodRead",
            request_serializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodReadResponse.FromString,
        )
        self.WarehouseDeliveryMethodUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodService/WarehouseDeliveryMethodUpdate",
            request_serializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodUpdateResponse.FromString,
        )
        self.WarehouseDeliveryMethodDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodService/WarehouseDeliveryMethodDelete",
            request_serializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodDeleteResponse.FromString,
        )


class WarehouseDeliveryMethodServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def WarehouseDeliveryMethodCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseDeliveryMethodRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseDeliveryMethodUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseDeliveryMethodDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_WarehouseDeliveryMethodServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "WarehouseDeliveryMethodCreate": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseDeliveryMethodCreate,
            request_deserializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodCreateResponse.SerializeToString,
        ),
        "WarehouseDeliveryMethodRead": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseDeliveryMethodRead,
            request_deserializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodReadResponse.SerializeToString,
        ),
        "WarehouseDeliveryMethodUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseDeliveryMethodUpdate,
            request_deserializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodUpdateResponse.SerializeToString,
        ),
        "WarehouseDeliveryMethodDelete": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseDeliveryMethodDelete,
            request_deserializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class WarehouseDeliveryMethodService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def WarehouseDeliveryMethodCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodService/WarehouseDeliveryMethodCreate",
            v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodCreateRequest.SerializeToString,
            v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseDeliveryMethodRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodService/WarehouseDeliveryMethodRead",
            v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodReadRequest.SerializeToString,
            v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseDeliveryMethodUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodService/WarehouseDeliveryMethodUpdate",
            v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodUpdateRequest.SerializeToString,
            v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseDeliveryMethodDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodService/WarehouseDeliveryMethodDelete",
            v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodDeleteRequest.SerializeToString,
            v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
