# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.stock import picking_pb2 as v1_dot_stock_dot_picking__pb2


class PickingServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.PickingCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingCreate",
            request_serializer=v1_dot_stock_dot_picking__pb2.PickingCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.PickingCreateResponse.FromString,
        )
        self.PickingRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingRead",
            request_serializer=v1_dot_stock_dot_picking__pb2.PickingReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.PickingReadResponse.FromString,
        )
        self.PickingUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingUpdate",
            request_serializer=v1_dot_stock_dot_picking__pb2.PickingUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.PickingUpdateResponse.FromString,
        )
        self.PickingDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingDelete",
            request_serializer=v1_dot_stock_dot_picking__pb2.PickingDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.PickingDeleteResponse.FromString,
        )
        self.UserCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/UserCreate",
            request_serializer=v1_dot_stock_dot_picking__pb2.UserCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.UserCreateResponse.FromString,
        )
        self.UserRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/UserRead",
            request_serializer=v1_dot_stock_dot_picking__pb2.UserReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.UserReadResponse.FromString,
        )
        self.UserUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/UserUpdate",
            request_serializer=v1_dot_stock_dot_picking__pb2.UserUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.UserUpdateResponse.FromString,
        )
        self.UserDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/UserDelete",
            request_serializer=v1_dot_stock_dot_picking__pb2.UserDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.UserDeleteResponse.FromString,
        )
        self.AttachmentCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/AttachmentCreate",
            request_serializer=v1_dot_stock_dot_picking__pb2.AttachmentCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.AttachmentCreateResponse.FromString,
        )
        self.AttachmentRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/AttachmentRead",
            request_serializer=v1_dot_stock_dot_picking__pb2.AttachmentReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.AttachmentReadResponse.FromString,
        )
        self.AttachmentUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/AttachmentUpdate",
            request_serializer=v1_dot_stock_dot_picking__pb2.AttachmentUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.AttachmentUpdateResponse.FromString,
        )
        self.AttachmentDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/AttachmentDelete",
            request_serializer=v1_dot_stock_dot_picking__pb2.AttachmentDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.AttachmentDeleteResponse.FromString,
        )
        self.CarrierCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/CarrierCreate",
            request_serializer=v1_dot_stock_dot_picking__pb2.CarrierCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.CarrierCreateResponse.FromString,
        )
        self.CarrierRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/CarrierRead",
            request_serializer=v1_dot_stock_dot_picking__pb2.CarrierReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.CarrierReadResponse.FromString,
        )
        self.CarrierUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/CarrierUpdate",
            request_serializer=v1_dot_stock_dot_picking__pb2.CarrierUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.CarrierUpdateResponse.FromString,
        )
        self.CarrierDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/CarrierDelete",
            request_serializer=v1_dot_stock_dot_picking__pb2.CarrierDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.CarrierDeleteResponse.FromString,
        )
        self.ProcurementGroupCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/ProcurementGroupCreate",
            request_serializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupCreateResponse.FromString,
        )
        self.ProcurementGroupRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/ProcurementGroupRead",
            request_serializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupReadResponse.FromString,
        )
        self.ProcurementGroupUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/ProcurementGroupUpdate",
            request_serializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupUpdateResponse.FromString,
        )
        self.ProcurementGroupDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/ProcurementGroupDelete",
            request_serializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupDeleteResponse.FromString,
        )


class PickingServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def PickingCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UserCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UserRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UserUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UserDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AttachmentCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AttachmentRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AttachmentUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AttachmentDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CarrierCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CarrierRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CarrierUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CarrierDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProcurementGroupCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProcurementGroupRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProcurementGroupUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProcurementGroupDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_PickingServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "PickingCreate": grpc.unary_unary_rpc_method_handler(
            servicer.PickingCreate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.PickingCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.PickingCreateResponse.SerializeToString,
        ),
        "PickingRead": grpc.unary_unary_rpc_method_handler(
            servicer.PickingRead,
            request_deserializer=v1_dot_stock_dot_picking__pb2.PickingReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.PickingReadResponse.SerializeToString,
        ),
        "PickingUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.PickingUpdate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.PickingUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.PickingUpdateResponse.SerializeToString,
        ),
        "PickingDelete": grpc.unary_unary_rpc_method_handler(
            servicer.PickingDelete,
            request_deserializer=v1_dot_stock_dot_picking__pb2.PickingDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.PickingDeleteResponse.SerializeToString,
        ),
        "UserCreate": grpc.unary_unary_rpc_method_handler(
            servicer.UserCreate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.UserCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.UserCreateResponse.SerializeToString,
        ),
        "UserRead": grpc.unary_unary_rpc_method_handler(
            servicer.UserRead,
            request_deserializer=v1_dot_stock_dot_picking__pb2.UserReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.UserReadResponse.SerializeToString,
        ),
        "UserUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.UserUpdate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.UserUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.UserUpdateResponse.SerializeToString,
        ),
        "UserDelete": grpc.unary_unary_rpc_method_handler(
            servicer.UserDelete,
            request_deserializer=v1_dot_stock_dot_picking__pb2.UserDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.UserDeleteResponse.SerializeToString,
        ),
        "AttachmentCreate": grpc.unary_unary_rpc_method_handler(
            servicer.AttachmentCreate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.AttachmentCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.AttachmentCreateResponse.SerializeToString,
        ),
        "AttachmentRead": grpc.unary_unary_rpc_method_handler(
            servicer.AttachmentRead,
            request_deserializer=v1_dot_stock_dot_picking__pb2.AttachmentReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.AttachmentReadResponse.SerializeToString,
        ),
        "AttachmentUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.AttachmentUpdate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.AttachmentUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.AttachmentUpdateResponse.SerializeToString,
        ),
        "AttachmentDelete": grpc.unary_unary_rpc_method_handler(
            servicer.AttachmentDelete,
            request_deserializer=v1_dot_stock_dot_picking__pb2.AttachmentDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.AttachmentDeleteResponse.SerializeToString,
        ),
        "CarrierCreate": grpc.unary_unary_rpc_method_handler(
            servicer.CarrierCreate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.CarrierCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.CarrierCreateResponse.SerializeToString,
        ),
        "CarrierRead": grpc.unary_unary_rpc_method_handler(
            servicer.CarrierRead,
            request_deserializer=v1_dot_stock_dot_picking__pb2.CarrierReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.CarrierReadResponse.SerializeToString,
        ),
        "CarrierUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.CarrierUpdate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.CarrierUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.CarrierUpdateResponse.SerializeToString,
        ),
        "CarrierDelete": grpc.unary_unary_rpc_method_handler(
            servicer.CarrierDelete,
            request_deserializer=v1_dot_stock_dot_picking__pb2.CarrierDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.CarrierDeleteResponse.SerializeToString,
        ),
        "ProcurementGroupCreate": grpc.unary_unary_rpc_method_handler(
            servicer.ProcurementGroupCreate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupCreateResponse.SerializeToString,
        ),
        "ProcurementGroupRead": grpc.unary_unary_rpc_method_handler(
            servicer.ProcurementGroupRead,
            request_deserializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupReadResponse.SerializeToString,
        ),
        "ProcurementGroupUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.ProcurementGroupUpdate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupUpdateResponse.SerializeToString,
        ),
        "ProcurementGroupDelete": grpc.unary_unary_rpc_method_handler(
            servicer.ProcurementGroupDelete,
            request_deserializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.stock.picking.PickingService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class PickingService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def PickingCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingCreate",
            v1_dot_stock_dot_picking__pb2.PickingCreateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.PickingCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingRead",
            v1_dot_stock_dot_picking__pb2.PickingReadRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.PickingReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingUpdate",
            v1_dot_stock_dot_picking__pb2.PickingUpdateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.PickingUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingDelete",
            v1_dot_stock_dot_picking__pb2.PickingDeleteRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.PickingDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UserCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/UserCreate",
            v1_dot_stock_dot_picking__pb2.UserCreateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.UserCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UserRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/UserRead",
            v1_dot_stock_dot_picking__pb2.UserReadRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.UserReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UserUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/UserUpdate",
            v1_dot_stock_dot_picking__pb2.UserUpdateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.UserUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UserDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/UserDelete",
            v1_dot_stock_dot_picking__pb2.UserDeleteRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.UserDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AttachmentCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/AttachmentCreate",
            v1_dot_stock_dot_picking__pb2.AttachmentCreateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.AttachmentCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AttachmentRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/AttachmentRead",
            v1_dot_stock_dot_picking__pb2.AttachmentReadRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.AttachmentReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AttachmentUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/AttachmentUpdate",
            v1_dot_stock_dot_picking__pb2.AttachmentUpdateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.AttachmentUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AttachmentDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/AttachmentDelete",
            v1_dot_stock_dot_picking__pb2.AttachmentDeleteRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.AttachmentDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CarrierCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/CarrierCreate",
            v1_dot_stock_dot_picking__pb2.CarrierCreateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.CarrierCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CarrierRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/CarrierRead",
            v1_dot_stock_dot_picking__pb2.CarrierReadRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.CarrierReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CarrierUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/CarrierUpdate",
            v1_dot_stock_dot_picking__pb2.CarrierUpdateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.CarrierUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CarrierDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/CarrierDelete",
            v1_dot_stock_dot_picking__pb2.CarrierDeleteRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.CarrierDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProcurementGroupCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/ProcurementGroupCreate",
            v1_dot_stock_dot_picking__pb2.ProcurementGroupCreateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.ProcurementGroupCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProcurementGroupRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/ProcurementGroupRead",
            v1_dot_stock_dot_picking__pb2.ProcurementGroupReadRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.ProcurementGroupReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProcurementGroupUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/ProcurementGroupUpdate",
            v1_dot_stock_dot_picking__pb2.ProcurementGroupUpdateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.ProcurementGroupUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProcurementGroupDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/ProcurementGroupDelete",
            v1_dot_stock_dot_picking__pb2.ProcurementGroupDeleteRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.ProcurementGroupDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
