# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.stock import stock_pb2 as v1_dot_stock_dot_stock__pb2


class StockServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ProductCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/ProductCreate",
            request_serializer=v1_dot_stock_dot_stock__pb2.ProductCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.ProductCreateResponse.FromString,
        )
        self.ProductRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/ProductRead",
            request_serializer=v1_dot_stock_dot_stock__pb2.ProductReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.ProductReadResponse.FromString,
        )
        self.ProductUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/ProductUpdate",
            request_serializer=v1_dot_stock_dot_stock__pb2.ProductUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.ProductUpdateResponse.FromString,
        )
        self.ProductDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/ProductDelete",
            request_serializer=v1_dot_stock_dot_stock__pb2.ProductDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.ProductDeleteResponse.FromString,
        )
        self.UomCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/UomCreate",
            request_serializer=v1_dot_stock_dot_stock__pb2.UomCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.UomCreateResponse.FromString,
        )
        self.UomRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/UomRead",
            request_serializer=v1_dot_stock_dot_stock__pb2.UomReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.UomReadResponse.FromString,
        )
        self.UomUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/UomUpdate",
            request_serializer=v1_dot_stock_dot_stock__pb2.UomUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.UomUpdateResponse.FromString,
        )
        self.UomDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/UomDelete",
            request_serializer=v1_dot_stock_dot_stock__pb2.UomDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.UomDeleteResponse.FromString,
        )
        self.QuantCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/QuantCreate",
            request_serializer=v1_dot_stock_dot_stock__pb2.QuantCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.QuantCreateResponse.FromString,
        )
        self.QuantRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/QuantRead",
            request_serializer=v1_dot_stock_dot_stock__pb2.QuantReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.QuantReadResponse.FromString,
        )
        self.QuantUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/QuantUpdate",
            request_serializer=v1_dot_stock_dot_stock__pb2.QuantUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.QuantUpdateResponse.FromString,
        )
        self.QuantDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/QuantDelete",
            request_serializer=v1_dot_stock_dot_stock__pb2.QuantDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.QuantDeleteResponse.FromString,
        )
        self.LocationCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/LocationCreate",
            request_serializer=v1_dot_stock_dot_stock__pb2.LocationCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.LocationCreateResponse.FromString,
        )
        self.LocationRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/LocationRead",
            request_serializer=v1_dot_stock_dot_stock__pb2.LocationReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.LocationReadResponse.FromString,
        )
        self.LocationUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/LocationUpdate",
            request_serializer=v1_dot_stock_dot_stock__pb2.LocationUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.LocationUpdateResponse.FromString,
        )
        self.LocationDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/LocationDelete",
            request_serializer=v1_dot_stock_dot_stock__pb2.LocationDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.LocationDeleteResponse.FromString,
        )
        self.WarehouseCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/WarehouseCreate",
            request_serializer=v1_dot_stock_dot_stock__pb2.WarehouseCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.WarehouseCreateResponse.FromString,
        )
        self.WarehouseRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/WarehouseRead",
            request_serializer=v1_dot_stock_dot_stock__pb2.WarehouseReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.WarehouseReadResponse.FromString,
        )
        self.WarehouseUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/WarehouseUpdate",
            request_serializer=v1_dot_stock_dot_stock__pb2.WarehouseUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.WarehouseUpdateResponse.FromString,
        )
        self.WarehouseDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/WarehouseDelete",
            request_serializer=v1_dot_stock_dot_stock__pb2.WarehouseDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.WarehouseDeleteResponse.FromString,
        )
        self.PickingTypeCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/PickingTypeCreate",
            request_serializer=v1_dot_stock_dot_stock__pb2.PickingTypeCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.PickingTypeCreateResponse.FromString,
        )
        self.PickingTypeRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/PickingTypeRead",
            request_serializer=v1_dot_stock_dot_stock__pb2.PickingTypeReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.PickingTypeReadResponse.FromString,
        )
        self.PickingTypeUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/PickingTypeUpdate",
            request_serializer=v1_dot_stock_dot_stock__pb2.PickingTypeUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.PickingTypeUpdateResponse.FromString,
        )
        self.PickingTypeDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/PickingTypeDelete",
            request_serializer=v1_dot_stock_dot_stock__pb2.PickingTypeDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.PickingTypeDeleteResponse.FromString,
        )
        self.RouteCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/RouteCreate",
            request_serializer=v1_dot_stock_dot_stock__pb2.RouteCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.RouteCreateResponse.FromString,
        )
        self.RouteRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/RouteRead",
            request_serializer=v1_dot_stock_dot_stock__pb2.RouteReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.RouteReadResponse.FromString,
        )
        self.RouteUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/RouteUpdate",
            request_serializer=v1_dot_stock_dot_stock__pb2.RouteUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.RouteUpdateResponse.FromString,
        )
        self.RouteDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/RouteDelete",
            request_serializer=v1_dot_stock_dot_stock__pb2.RouteDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.RouteDeleteResponse.FromString,
        )
        self.RuleCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/RuleCreate",
            request_serializer=v1_dot_stock_dot_stock__pb2.RuleCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.RuleCreateResponse.FromString,
        )
        self.RuleRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/RuleRead",
            request_serializer=v1_dot_stock_dot_stock__pb2.RuleReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.RuleReadResponse.FromString,
        )
        self.RuleUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/RuleUpdate",
            request_serializer=v1_dot_stock_dot_stock__pb2.RuleUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.RuleUpdateResponse.FromString,
        )
        self.RuleDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/RuleDelete",
            request_serializer=v1_dot_stock_dot_stock__pb2.RuleDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.RuleDeleteResponse.FromString,
        )


class StockServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ProductCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UomCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UomRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UomUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UomDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def QuantCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def QuantRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def QuantUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def QuantDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def LocationCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def LocationRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def LocationUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def LocationDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingTypeCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingTypeRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingTypeUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingTypeDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RouteCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RouteRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RouteUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RouteDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RuleCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RuleRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RuleUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RuleDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_StockServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ProductCreate": grpc.unary_unary_rpc_method_handler(
            servicer.ProductCreate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.ProductCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.ProductCreateResponse.SerializeToString,
        ),
        "ProductRead": grpc.unary_unary_rpc_method_handler(
            servicer.ProductRead,
            request_deserializer=v1_dot_stock_dot_stock__pb2.ProductReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.ProductReadResponse.SerializeToString,
        ),
        "ProductUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.ProductUpdate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.ProductUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.ProductUpdateResponse.SerializeToString,
        ),
        "ProductDelete": grpc.unary_unary_rpc_method_handler(
            servicer.ProductDelete,
            request_deserializer=v1_dot_stock_dot_stock__pb2.ProductDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.ProductDeleteResponse.SerializeToString,
        ),
        "UomCreate": grpc.unary_unary_rpc_method_handler(
            servicer.UomCreate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.UomCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.UomCreateResponse.SerializeToString,
        ),
        "UomRead": grpc.unary_unary_rpc_method_handler(
            servicer.UomRead,
            request_deserializer=v1_dot_stock_dot_stock__pb2.UomReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.UomReadResponse.SerializeToString,
        ),
        "UomUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.UomUpdate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.UomUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.UomUpdateResponse.SerializeToString,
        ),
        "UomDelete": grpc.unary_unary_rpc_method_handler(
            servicer.UomDelete,
            request_deserializer=v1_dot_stock_dot_stock__pb2.UomDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.UomDeleteResponse.SerializeToString,
        ),
        "QuantCreate": grpc.unary_unary_rpc_method_handler(
            servicer.QuantCreate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.QuantCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.QuantCreateResponse.SerializeToString,
        ),
        "QuantRead": grpc.unary_unary_rpc_method_handler(
            servicer.QuantRead,
            request_deserializer=v1_dot_stock_dot_stock__pb2.QuantReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.QuantReadResponse.SerializeToString,
        ),
        "QuantUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.QuantUpdate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.QuantUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.QuantUpdateResponse.SerializeToString,
        ),
        "QuantDelete": grpc.unary_unary_rpc_method_handler(
            servicer.QuantDelete,
            request_deserializer=v1_dot_stock_dot_stock__pb2.QuantDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.QuantDeleteResponse.SerializeToString,
        ),
        "LocationCreate": grpc.unary_unary_rpc_method_handler(
            servicer.LocationCreate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.LocationCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.LocationCreateResponse.SerializeToString,
        ),
        "LocationRead": grpc.unary_unary_rpc_method_handler(
            servicer.LocationRead,
            request_deserializer=v1_dot_stock_dot_stock__pb2.LocationReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.LocationReadResponse.SerializeToString,
        ),
        "LocationUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.LocationUpdate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.LocationUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.LocationUpdateResponse.SerializeToString,
        ),
        "LocationDelete": grpc.unary_unary_rpc_method_handler(
            servicer.LocationDelete,
            request_deserializer=v1_dot_stock_dot_stock__pb2.LocationDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.LocationDeleteResponse.SerializeToString,
        ),
        "WarehouseCreate": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseCreate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.WarehouseCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.WarehouseCreateResponse.SerializeToString,
        ),
        "WarehouseRead": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseRead,
            request_deserializer=v1_dot_stock_dot_stock__pb2.WarehouseReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.WarehouseReadResponse.SerializeToString,
        ),
        "WarehouseUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseUpdate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.WarehouseUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.WarehouseUpdateResponse.SerializeToString,
        ),
        "WarehouseDelete": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseDelete,
            request_deserializer=v1_dot_stock_dot_stock__pb2.WarehouseDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.WarehouseDeleteResponse.SerializeToString,
        ),
        "PickingTypeCreate": grpc.unary_unary_rpc_method_handler(
            servicer.PickingTypeCreate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.PickingTypeCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.PickingTypeCreateResponse.SerializeToString,
        ),
        "PickingTypeRead": grpc.unary_unary_rpc_method_handler(
            servicer.PickingTypeRead,
            request_deserializer=v1_dot_stock_dot_stock__pb2.PickingTypeReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.PickingTypeReadResponse.SerializeToString,
        ),
        "PickingTypeUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.PickingTypeUpdate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.PickingTypeUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.PickingTypeUpdateResponse.SerializeToString,
        ),
        "PickingTypeDelete": grpc.unary_unary_rpc_method_handler(
            servicer.PickingTypeDelete,
            request_deserializer=v1_dot_stock_dot_stock__pb2.PickingTypeDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.PickingTypeDeleteResponse.SerializeToString,
        ),
        "RouteCreate": grpc.unary_unary_rpc_method_handler(
            servicer.RouteCreate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.RouteCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.RouteCreateResponse.SerializeToString,
        ),
        "RouteRead": grpc.unary_unary_rpc_method_handler(
            servicer.RouteRead,
            request_deserializer=v1_dot_stock_dot_stock__pb2.RouteReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.RouteReadResponse.SerializeToString,
        ),
        "RouteUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.RouteUpdate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.RouteUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.RouteUpdateResponse.SerializeToString,
        ),
        "RouteDelete": grpc.unary_unary_rpc_method_handler(
            servicer.RouteDelete,
            request_deserializer=v1_dot_stock_dot_stock__pb2.RouteDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.RouteDeleteResponse.SerializeToString,
        ),
        "RuleCreate": grpc.unary_unary_rpc_method_handler(
            servicer.RuleCreate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.RuleCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.RuleCreateResponse.SerializeToString,
        ),
        "RuleRead": grpc.unary_unary_rpc_method_handler(
            servicer.RuleRead,
            request_deserializer=v1_dot_stock_dot_stock__pb2.RuleReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.RuleReadResponse.SerializeToString,
        ),
        "RuleUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.RuleUpdate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.RuleUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.RuleUpdateResponse.SerializeToString,
        ),
        "RuleDelete": grpc.unary_unary_rpc_method_handler(
            servicer.RuleDelete,
            request_deserializer=v1_dot_stock_dot_stock__pb2.RuleDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.RuleDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.stock.StockService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class StockService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ProductCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/ProductCreate",
            v1_dot_stock_dot_stock__pb2.ProductCreateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.ProductCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/ProductRead",
            v1_dot_stock_dot_stock__pb2.ProductReadRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.ProductReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/ProductUpdate",
            v1_dot_stock_dot_stock__pb2.ProductUpdateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.ProductUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/ProductDelete",
            v1_dot_stock_dot_stock__pb2.ProductDeleteRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.ProductDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UomCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/UomCreate",
            v1_dot_stock_dot_stock__pb2.UomCreateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.UomCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UomRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/UomRead",
            v1_dot_stock_dot_stock__pb2.UomReadRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.UomReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UomUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/UomUpdate",
            v1_dot_stock_dot_stock__pb2.UomUpdateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.UomUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UomDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/UomDelete",
            v1_dot_stock_dot_stock__pb2.UomDeleteRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.UomDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def QuantCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/QuantCreate",
            v1_dot_stock_dot_stock__pb2.QuantCreateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.QuantCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def QuantRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/QuantRead",
            v1_dot_stock_dot_stock__pb2.QuantReadRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.QuantReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def QuantUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/QuantUpdate",
            v1_dot_stock_dot_stock__pb2.QuantUpdateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.QuantUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def QuantDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/QuantDelete",
            v1_dot_stock_dot_stock__pb2.QuantDeleteRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.QuantDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def LocationCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/LocationCreate",
            v1_dot_stock_dot_stock__pb2.LocationCreateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.LocationCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def LocationRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/LocationRead",
            v1_dot_stock_dot_stock__pb2.LocationReadRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.LocationReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def LocationUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/LocationUpdate",
            v1_dot_stock_dot_stock__pb2.LocationUpdateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.LocationUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def LocationDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/LocationDelete",
            v1_dot_stock_dot_stock__pb2.LocationDeleteRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.LocationDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/WarehouseCreate",
            v1_dot_stock_dot_stock__pb2.WarehouseCreateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.WarehouseCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/WarehouseRead",
            v1_dot_stock_dot_stock__pb2.WarehouseReadRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.WarehouseReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/WarehouseUpdate",
            v1_dot_stock_dot_stock__pb2.WarehouseUpdateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.WarehouseUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/WarehouseDelete",
            v1_dot_stock_dot_stock__pb2.WarehouseDeleteRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.WarehouseDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingTypeCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/PickingTypeCreate",
            v1_dot_stock_dot_stock__pb2.PickingTypeCreateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.PickingTypeCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingTypeRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/PickingTypeRead",
            v1_dot_stock_dot_stock__pb2.PickingTypeReadRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.PickingTypeReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingTypeUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/PickingTypeUpdate",
            v1_dot_stock_dot_stock__pb2.PickingTypeUpdateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.PickingTypeUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingTypeDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/PickingTypeDelete",
            v1_dot_stock_dot_stock__pb2.PickingTypeDeleteRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.PickingTypeDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RouteCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/RouteCreate",
            v1_dot_stock_dot_stock__pb2.RouteCreateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.RouteCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RouteRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/RouteRead",
            v1_dot_stock_dot_stock__pb2.RouteReadRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.RouteReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RouteUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/RouteUpdate",
            v1_dot_stock_dot_stock__pb2.RouteUpdateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.RouteUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RouteDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/RouteDelete",
            v1_dot_stock_dot_stock__pb2.RouteDeleteRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.RouteDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RuleCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/RuleCreate",
            v1_dot_stock_dot_stock__pb2.RuleCreateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.RuleCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RuleRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/RuleRead",
            v1_dot_stock_dot_stock__pb2.RuleReadRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.RuleReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RuleUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/RuleUpdate",
            v1_dot_stock_dot_stock__pb2.RuleUpdateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.RuleUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RuleDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/RuleDelete",
            v1_dot_stock_dot_stock__pb2.RuleDeleteRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.RuleDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
