# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/stock.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14v1/stock/stock.proto\x12\x19pro.omni.oms.api.v1.stock\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xc1\x01\n\x07Product\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x16\n\x0eproduct_doc_id\x18\x02 \x01(\t\x12\x17\n\x0ftemplate_doc_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xae\x01\n\x03Uom\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nuom_doc_id\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xf5\x01\n\x05Quant\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nproduct_id\x18\x02 \x01(\x05\x12\x13\n\x0blocation_id\x18\x03 \x01(\x05\x12\x0c\n\x04lote\x18\x04 \x01(\t\x12\x1a\n\x12\x61vailable_quantity\x18\x05 \x01(\x02\x12\x10\n\x08quantity\x18\x06 \x01(\x02\x12\x0e\n\x06uom_id\x18\x07 \x01(\x05\x12*\n\x06\x61\x63tive\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\t \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xf0\x01\n\x08Location\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tparent_id\x18\x03 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x15\n\rtype_location\x18\x05 \x01(\t\x12\x0f\n\x07\x62\x61rcode\x18\x06 \x01(\t\x12\x14\n\x0cwarehouse_id\x18\x07 \x01(\x05\x12*\n\x06\x61\x63tive\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\t \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x92\x02\n\tWarehouse\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x12\n\ncountry_id\x18\x04 \x01(\x05\x12\x37\n\x16territory_matrix_value\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07\x61\x64\x64ress\x18\x06 \x01(\t\x12\x12\n\ncomplement\x18\x07 \x01(\t\x12*\n\x06\x61\x63tive\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\t \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xf1\x03\n\x0bPickingType\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rsequence_code\x18\x03 \x01(\t\x12\x14\n\x0cwarehouse_id\x18\x04 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x05 \x01(\t\x12\x1e\n\x16return_picking_type_id\x18\x06 \x01(\x05\x12\x33\n\x0fshow_operations\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x31\n\rshow_reserved\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1f\n\x17\x64\x65\x66\x61ult_location_src_id\x18\t \x01(\x05\x12 \n\x18\x64\x65\x66\x61ult_location_dest_id\x18\n \x01(\x05\x12\x0e\n\x06prefix\x18\x0b \x01(\t\x12\x0f\n\x07padding\x18\x0c \x01(\x05\x12\x18\n\x10number_increment\x18\r \x01(\x05\x12\x1a\n\x12number_next_actual\x18\x0e \x01(\x05\x12*\n\x06\x61\x63tive\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x10 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x9e\x03\n\x05Route\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08sequence\x18\x03 \x01(\x05\x12<\n\x18product_categ_selectable\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12product_selectable\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12packing_selectable\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14warehouse_selectable\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x14\n\x0cwarehouse_id\x18\x08 \x01(\x05\x12*\n\x06\x61\x63tive\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\n \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xb6\x02\n\x04Rule\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\t\x12\x17\n\x0fpicking_type_id\x18\x04 \x01(\x05\x12\x17\n\x0flocation_src_id\x18\x05 \x01(\x05\x12\x13\n\x0blocation_id\x18\x06 \x01(\x05\x12\x16\n\x0eprocure_method\x18\x07 \x01(\t\x12\x10\n\x08route_id\x18\x08 \x01(\x05\x12\x14\n\x0cwarehouse_id\x18\t \x01(\x05\x12\x10\n\x08sequence\x18\n \x01(\x05\x12*\n\x06\x61\x63tive\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x0c \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xb9\x01\n\x14ProductCreateRequest\x12\x16\n\x0eproduct_doc_id\x18\x01 \x01(\t\x12\x17\n\x0ftemplate_doc_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12*\n\x06\x61\x63tive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x15ProductCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x33\n\x07product\x18\x02 \x01(\x0b\x32".pro.omni.oms.api.v1.stock.Product"\xf0\x02\n\x12ProductReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd1\x01\n\x13ProductReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x34\n\x08products\x18\x03 \x03(\x0b\x32".pro.omni.oms.api.v1.stock.Product"\x83\x01\n\x14ProductUpdateRequest\x12\x33\n\x07product\x18\x01 \x01(\x0b\x32".pro.omni.oms.api.v1.stock.Product\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x15ProductUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x33\n\x07product\x18\x02 \x01(\x0b\x32".pro.omni.oms.api.v1.stock.Product"Z\n\x14ProductDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"b\n\x15ProductDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xa6\x01\n\x10UomCreateRequest\x12\x12\n\nuom_doc_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12*\n\x06\x61\x63tive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x8b\x01\n\x11UomCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12+\n\x03uom\x18\x02 \x01(\x0b\x32\x1e.pro.omni.oms.api.v1.stock.Uom"\xec\x02\n\x0eUomReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc5\x01\n\x0fUomReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12,\n\x04uoms\x18\x03 \x03(\x0b\x32\x1e.pro.omni.oms.api.v1.stock.Uom"w\n\x10UomUpdateRequest\x12+\n\x03uom\x18\x01 \x01(\x0b\x32\x1e.pro.omni.oms.api.v1.stock.Uom\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x8b\x01\n\x11UomUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12+\n\x03uom\x18\x02 \x01(\x0b\x32\x1e.pro.omni.oms.api.v1.stock.Uom"V\n\x10UomDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"^\n\x11UomDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xc1\x01\n\x12QuantCreateRequest\x12\x12\n\nproduct_id\x18\x01 \x01(\x05\x12\x13\n\x0blocation_id\x18\x02 \x01(\x05\x12\x0c\n\x04lote\x18\x03 \x01(\t\x12\x1a\n\x12\x61vailable_quantity\x18\x04 \x01(\x02\x12\x10\n\x08quantity\x18\x05 \x01(\x02\x12\x0e\n\x06uom_id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x91\x01\n\x13QuantCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12/\n\x05quant\x18\x02 \x01(\x0b\x32 .pro.omni.oms.api.v1.stock.Quant"\xee\x02\n\x10QuantReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xcb\x01\n\x11QuantReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x30\n\x06quants\x18\x03 \x03(\x0b\x32 .pro.omni.oms.api.v1.stock.Quant"}\n\x12QuantUpdateRequest\x12/\n\x05quant\x18\x01 \x01(\x0b\x32 .pro.omni.oms.api.v1.stock.Quant\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x91\x01\n\x13QuantUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12/\n\x05quant\x18\x02 \x01(\x0b\x32 .pro.omni.oms.api.v1.stock.Quant"X\n\x12QuantDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13QuantDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xe8\x01\n\x15LocationCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tparent_id\x18\x02 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x15\n\rtype_location\x18\x04 \x01(\t\x12\x0f\n\x07\x62\x61rcode\x18\x05 \x01(\t\x12\x14\n\x0cwarehouse_id\x18\x06 \x01(\x05\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9a\x01\n\x16LocationCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x35\n\x08location\x18\x02 \x01(\x0b\x32#.pro.omni.oms.api.v1.stock.Location"\xf1\x02\n\x13LocationReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd4\x01\n\x14LocationReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x36\n\tlocations\x18\x03 \x03(\x0b\x32#.pro.omni.oms.api.v1.stock.Location"\x86\x01\n\x15LocationUpdateRequest\x12\x35\n\x08location\x18\x01 \x01(\x0b\x32#.pro.omni.oms.api.v1.stock.Location\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9a\x01\n\x16LocationUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x35\n\x08location\x18\x02 \x01(\x0b\x32#.pro.omni.oms.api.v1.stock.Location"[\n\x15LocationDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"c\n\x16LocationDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8a\x02\n\x16WarehouseCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x12\n\ncountry_id\x18\x03 \x01(\x05\x12\x37\n\x16territory_matrix_value\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07\x61\x64\x64ress\x18\x05 \x01(\t\x12\x12\n\ncomplement\x18\x06 \x01(\t\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9d\x01\n\x17WarehouseCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x37\n\twarehouse\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.v1.stock.Warehouse"\xf2\x02\n\x14WarehouseReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd7\x01\n\x15WarehouseReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x38\n\nwarehouses\x18\x03 \x03(\x0b\x32$.pro.omni.oms.api.v1.stock.Warehouse"\x89\x01\n\x16WarehouseUpdateRequest\x12\x37\n\twarehouse\x18\x01 \x01(\x0b\x32$.pro.omni.oms.api.v1.stock.Warehouse\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9d\x01\n\x17WarehouseUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x37\n\twarehouse\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.v1.stock.Warehouse"\\\n\x16WarehouseDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"d\n\x17WarehouseDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xbd\x03\n\x18PickingTypeCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rsequence_code\x18\x02 \x01(\t\x12\x14\n\x0cwarehouse_id\x18\x03 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x1e\n\x16return_picking_type_id\x18\x05 \x01(\x05\x12\x33\n\x0fshow_operations\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x31\n\rshow_reserved\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1f\n\x17\x64\x65\x66\x61ult_location_src_id\x18\x08 \x01(\x05\x12 \n\x18\x64\x65\x66\x61ult_location_dest_id\x18\t \x01(\x05\x12\x0e\n\x06prefix\x18\n \x01(\t\x12\x0f\n\x07padding\x18\x0b \x01(\x05\x12\x18\n\x10number_increment\x18\x0c \x01(\x05\x12\x1a\n\x12number_next_actual\x18\r \x01(\x05\x12\x36\n\x07\x63ontext\x18\x0e \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa4\x01\n\x19PickingTypeCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12<\n\x0cpicking_type\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.PickingType"\xf4\x02\n\x16PickingTypeReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xde\x01\n\x17PickingTypeReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12=\n\rpicking_types\x18\x03 \x03(\x0b\x32&.pro.omni.oms.api.v1.stock.PickingType"\x90\x01\n\x18PickingTypeUpdateRequest\x12<\n\x0cpicking_type\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.PickingType\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa4\x01\n\x19PickingTypeUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12<\n\x0cpicking_type\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.PickingType"^\n\x18PickingTypeDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"f\n\x19PickingTypeDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xea\x02\n\x12RouteCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08sequence\x18\x02 \x01(\x05\x12<\n\x18product_categ_selectable\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12product_selectable\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12packing_selectable\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14warehouse_selectable\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x14\n\x0cwarehouse_id\x18\x07 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x91\x01\n\x13RouteCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12/\n\x05route\x18\x02 \x01(\x0b\x32 .pro.omni.oms.api.v1.stock.Route"\xee\x02\n\x10RouteReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xcb\x01\n\x11RouteReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x30\n\x06routes\x18\x03 \x03(\x0b\x32 .pro.omni.oms.api.v1.stock.Route"}\n\x12RouteUpdateRequest\x12/\n\x05route\x18\x01 \x01(\x0b\x32 .pro.omni.oms.api.v1.stock.Route\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x91\x01\n\x13RouteUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12/\n\x05route\x18\x02 \x01(\x0b\x32 .pro.omni.oms.api.v1.stock.Route"X\n\x12RouteDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13RouteDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x82\x02\n\x11RuleCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12\x17\n\x0fpicking_type_id\x18\x03 \x01(\x05\x12\x17\n\x0flocation_src_id\x18\x04 \x01(\x05\x12\x13\n\x0blocation_id\x18\x05 \x01(\x05\x12\x16\n\x0eprocure_method\x18\x06 \x01(\t\x12\x10\n\x08route_id\x18\x07 \x01(\x05\x12\x14\n\x0cwarehouse_id\x18\x08 \x01(\x05\x12\x10\n\x08sequence\x18\t \x01(\x05\x12\x36\n\x07\x63ontext\x18\n \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x8e\x01\n\x12RuleCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12-\n\x04rule\x18\x02 \x01(\x0b\x32\x1f.pro.omni.oms.api.v1.stock.Rule"\xed\x02\n\x0fRuleReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc8\x01\n\x10RuleReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12.\n\x05rules\x18\x03 \x03(\x0b\x32\x1f.pro.omni.oms.api.v1.stock.Rule"z\n\x11RuleUpdateRequest\x12-\n\x04rule\x18\x01 \x01(\x0b\x32\x1f.pro.omni.oms.api.v1.stock.Rule\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x8e\x01\n\x12RuleUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12-\n\x04rule\x18\x02 \x01(\x0b\x32\x1f.pro.omni.oms.api.v1.stock.Rule"W\n\x11RuleDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"_\n\x12RuleDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xf1\x1c\n\x0cStockService\x12t\n\rProductCreate\x12/.pro.omni.oms.api.v1.stock.ProductCreateRequest\x1a\x30.pro.omni.oms.api.v1.stock.ProductCreateResponse"\x00\x12n\n\x0bProductRead\x12-.pro.omni.oms.api.v1.stock.ProductReadRequest\x1a..pro.omni.oms.api.v1.stock.ProductReadResponse"\x00\x12t\n\rProductUpdate\x12/.pro.omni.oms.api.v1.stock.ProductUpdateRequest\x1a\x30.pro.omni.oms.api.v1.stock.ProductUpdateResponse"\x00\x12t\n\rProductDelete\x12/.pro.omni.oms.api.v1.stock.ProductDeleteRequest\x1a\x30.pro.omni.oms.api.v1.stock.ProductDeleteResponse"\x00\x12h\n\tUomCreate\x12+.pro.omni.oms.api.v1.stock.UomCreateRequest\x1a,.pro.omni.oms.api.v1.stock.UomCreateResponse"\x00\x12\x62\n\x07UomRead\x12).pro.omni.oms.api.v1.stock.UomReadRequest\x1a*.pro.omni.oms.api.v1.stock.UomReadResponse"\x00\x12h\n\tUomUpdate\x12+.pro.omni.oms.api.v1.stock.UomUpdateRequest\x1a,.pro.omni.oms.api.v1.stock.UomUpdateResponse"\x00\x12h\n\tUomDelete\x12+.pro.omni.oms.api.v1.stock.UomDeleteRequest\x1a,.pro.omni.oms.api.v1.stock.UomDeleteResponse"\x00\x12n\n\x0bQuantCreate\x12-.pro.omni.oms.api.v1.stock.QuantCreateRequest\x1a..pro.omni.oms.api.v1.stock.QuantCreateResponse"\x00\x12h\n\tQuantRead\x12+.pro.omni.oms.api.v1.stock.QuantReadRequest\x1a,.pro.omni.oms.api.v1.stock.QuantReadResponse"\x00\x12n\n\x0bQuantUpdate\x12-.pro.omni.oms.api.v1.stock.QuantUpdateRequest\x1a..pro.omni.oms.api.v1.stock.QuantUpdateResponse"\x00\x12n\n\x0bQuantDelete\x12-.pro.omni.oms.api.v1.stock.QuantDeleteRequest\x1a..pro.omni.oms.api.v1.stock.QuantDeleteResponse"\x00\x12w\n\x0eLocationCreate\x12\x30.pro.omni.oms.api.v1.stock.LocationCreateRequest\x1a\x31.pro.omni.oms.api.v1.stock.LocationCreateResponse"\x00\x12q\n\x0cLocationRead\x12..pro.omni.oms.api.v1.stock.LocationReadRequest\x1a/.pro.omni.oms.api.v1.stock.LocationReadResponse"\x00\x12w\n\x0eLocationUpdate\x12\x30.pro.omni.oms.api.v1.stock.LocationUpdateRequest\x1a\x31.pro.omni.oms.api.v1.stock.LocationUpdateResponse"\x00\x12w\n\x0eLocationDelete\x12\x30.pro.omni.oms.api.v1.stock.LocationDeleteRequest\x1a\x31.pro.omni.oms.api.v1.stock.LocationDeleteResponse"\x00\x12z\n\x0fWarehouseCreate\x12\x31.pro.omni.oms.api.v1.stock.WarehouseCreateRequest\x1a\x32.pro.omni.oms.api.v1.stock.WarehouseCreateResponse"\x00\x12t\n\rWarehouseRead\x12/.pro.omni.oms.api.v1.stock.WarehouseReadRequest\x1a\x30.pro.omni.oms.api.v1.stock.WarehouseReadResponse"\x00\x12z\n\x0fWarehouseUpdate\x12\x31.pro.omni.oms.api.v1.stock.WarehouseUpdateRequest\x1a\x32.pro.omni.oms.api.v1.stock.WarehouseUpdateResponse"\x00\x12z\n\x0fWarehouseDelete\x12\x31.pro.omni.oms.api.v1.stock.WarehouseDeleteRequest\x1a\x32.pro.omni.oms.api.v1.stock.WarehouseDeleteResponse"\x00\x12\x80\x01\n\x11PickingTypeCreate\x12\x33.pro.omni.oms.api.v1.stock.PickingTypeCreateRequest\x1a\x34.pro.omni.oms.api.v1.stock.PickingTypeCreateResponse"\x00\x12z\n\x0fPickingTypeRead\x12\x31.pro.omni.oms.api.v1.stock.PickingTypeReadRequest\x1a\x32.pro.omni.oms.api.v1.stock.PickingTypeReadResponse"\x00\x12\x80\x01\n\x11PickingTypeUpdate\x12\x33.pro.omni.oms.api.v1.stock.PickingTypeUpdateRequest\x1a\x34.pro.omni.oms.api.v1.stock.PickingTypeUpdateResponse"\x00\x12\x80\x01\n\x11PickingTypeDelete\x12\x33.pro.omni.oms.api.v1.stock.PickingTypeDeleteRequest\x1a\x34.pro.omni.oms.api.v1.stock.PickingTypeDeleteResponse"\x00\x12n\n\x0bRouteCreate\x12-.pro.omni.oms.api.v1.stock.RouteCreateRequest\x1a..pro.omni.oms.api.v1.stock.RouteCreateResponse"\x00\x12h\n\tRouteRead\x12+.pro.omni.oms.api.v1.stock.RouteReadRequest\x1a,.pro.omni.oms.api.v1.stock.RouteReadResponse"\x00\x12n\n\x0bRouteUpdate\x12-.pro.omni.oms.api.v1.stock.RouteUpdateRequest\x1a..pro.omni.oms.api.v1.stock.RouteUpdateResponse"\x00\x12n\n\x0bRouteDelete\x12-.pro.omni.oms.api.v1.stock.RouteDeleteRequest\x1a..pro.omni.oms.api.v1.stock.RouteDeleteResponse"\x00\x12k\n\nRuleCreate\x12,.pro.omni.oms.api.v1.stock.RuleCreateRequest\x1a-.pro.omni.oms.api.v1.stock.RuleCreateResponse"\x00\x12\x65\n\x08RuleRead\x12*.pro.omni.oms.api.v1.stock.RuleReadRequest\x1a+.pro.omni.oms.api.v1.stock.RuleReadResponse"\x00\x12k\n\nRuleUpdate\x12,.pro.omni.oms.api.v1.stock.RuleUpdateRequest\x1a-.pro.omni.oms.api.v1.stock.RuleUpdateResponse"\x00\x12k\n\nRuleDelete\x12,.pro.omni.oms.api.v1.stock.RuleDeleteRequest\x1a-.pro.omni.oms.api.v1.stock.RuleDeleteResponse"\x00\x62\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.stock_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _PRODUCT._serialized_start = 133
    _PRODUCT._serialized_end = 326
    _UOM._serialized_start = 329
    _UOM._serialized_end = 503
    _QUANT._serialized_start = 506
    _QUANT._serialized_end = 751
    _LOCATION._serialized_start = 754
    _LOCATION._serialized_end = 994
    _WAREHOUSE._serialized_start = 997
    _WAREHOUSE._serialized_end = 1271
    _PICKINGTYPE._serialized_start = 1274
    _PICKINGTYPE._serialized_end = 1771
    _ROUTE._serialized_start = 1774
    _ROUTE._serialized_end = 2188
    _RULE._serialized_start = 2191
    _RULE._serialized_end = 2501
    _PRODUCTCREATEREQUEST._serialized_start = 2504
    _PRODUCTCREATEREQUEST._serialized_end = 2689
    _PRODUCTCREATERESPONSE._serialized_start = 2692
    _PRODUCTCREATERESPONSE._serialized_end = 2843
    _PRODUCTREADREQUEST._serialized_start = 2846
    _PRODUCTREADREQUEST._serialized_end = 3214
    _PRODUCTREADRESPONSE._serialized_start = 3217
    _PRODUCTREADRESPONSE._serialized_end = 3426
    _PRODUCTUPDATEREQUEST._serialized_start = 3429
    _PRODUCTUPDATEREQUEST._serialized_end = 3560
    _PRODUCTUPDATERESPONSE._serialized_start = 3563
    _PRODUCTUPDATERESPONSE._serialized_end = 3714
    _PRODUCTDELETEREQUEST._serialized_start = 3716
    _PRODUCTDELETEREQUEST._serialized_end = 3806
    _PRODUCTDELETERESPONSE._serialized_start = 3808
    _PRODUCTDELETERESPONSE._serialized_end = 3906
    _UOMCREATEREQUEST._serialized_start = 3909
    _UOMCREATEREQUEST._serialized_end = 4075
    _UOMCREATERESPONSE._serialized_start = 4078
    _UOMCREATERESPONSE._serialized_end = 4217
    _UOMREADREQUEST._serialized_start = 4220
    _UOMREADREQUEST._serialized_end = 4584
    _UOMREADRESPONSE._serialized_start = 4587
    _UOMREADRESPONSE._serialized_end = 4784
    _UOMUPDATEREQUEST._serialized_start = 4786
    _UOMUPDATEREQUEST._serialized_end = 4905
    _UOMUPDATERESPONSE._serialized_start = 4908
    _UOMUPDATERESPONSE._serialized_end = 5047
    _UOMDELETEREQUEST._serialized_start = 5049
    _UOMDELETEREQUEST._serialized_end = 5135
    _UOMDELETERESPONSE._serialized_start = 5137
    _UOMDELETERESPONSE._serialized_end = 5231
    _QUANTCREATEREQUEST._serialized_start = 5234
    _QUANTCREATEREQUEST._serialized_end = 5427
    _QUANTCREATERESPONSE._serialized_start = 5430
    _QUANTCREATERESPONSE._serialized_end = 5575
    _QUANTREADREQUEST._serialized_start = 5578
    _QUANTREADREQUEST._serialized_end = 5944
    _QUANTREADRESPONSE._serialized_start = 5947
    _QUANTREADRESPONSE._serialized_end = 6150
    _QUANTUPDATEREQUEST._serialized_start = 6152
    _QUANTUPDATEREQUEST._serialized_end = 6277
    _QUANTUPDATERESPONSE._serialized_start = 6280
    _QUANTUPDATERESPONSE._serialized_end = 6425
    _QUANTDELETEREQUEST._serialized_start = 6427
    _QUANTDELETEREQUEST._serialized_end = 6515
    _QUANTDELETERESPONSE._serialized_start = 6517
    _QUANTDELETERESPONSE._serialized_end = 6613
    _LOCATIONCREATEREQUEST._serialized_start = 6616
    _LOCATIONCREATEREQUEST._serialized_end = 6848
    _LOCATIONCREATERESPONSE._serialized_start = 6851
    _LOCATIONCREATERESPONSE._serialized_end = 7005
    _LOCATIONREADREQUEST._serialized_start = 7008
    _LOCATIONREADREQUEST._serialized_end = 7377
    _LOCATIONREADRESPONSE._serialized_start = 7380
    _LOCATIONREADRESPONSE._serialized_end = 7592
    _LOCATIONUPDATEREQUEST._serialized_start = 7595
    _LOCATIONUPDATEREQUEST._serialized_end = 7729
    _LOCATIONUPDATERESPONSE._serialized_start = 7732
    _LOCATIONUPDATERESPONSE._serialized_end = 7886
    _LOCATIONDELETEREQUEST._serialized_start = 7888
    _LOCATIONDELETEREQUEST._serialized_end = 7979
    _LOCATIONDELETERESPONSE._serialized_start = 7981
    _LOCATIONDELETERESPONSE._serialized_end = 8080
    _WAREHOUSECREATEREQUEST._serialized_start = 8083
    _WAREHOUSECREATEREQUEST._serialized_end = 8349
    _WAREHOUSECREATERESPONSE._serialized_start = 8352
    _WAREHOUSECREATERESPONSE._serialized_end = 8509
    _WAREHOUSEREADREQUEST._serialized_start = 8512
    _WAREHOUSEREADREQUEST._serialized_end = 8882
    _WAREHOUSEREADRESPONSE._serialized_start = 8885
    _WAREHOUSEREADRESPONSE._serialized_end = 9100
    _WAREHOUSEUPDATEREQUEST._serialized_start = 9103
    _WAREHOUSEUPDATEREQUEST._serialized_end = 9240
    _WAREHOUSEUPDATERESPONSE._serialized_start = 9243
    _WAREHOUSEUPDATERESPONSE._serialized_end = 9400
    _WAREHOUSEDELETEREQUEST._serialized_start = 9402
    _WAREHOUSEDELETEREQUEST._serialized_end = 9494
    _WAREHOUSEDELETERESPONSE._serialized_start = 9496
    _WAREHOUSEDELETERESPONSE._serialized_end = 9596
    _PICKINGTYPECREATEREQUEST._serialized_start = 9599
    _PICKINGTYPECREATEREQUEST._serialized_end = 10044
    _PICKINGTYPECREATERESPONSE._serialized_start = 10047
    _PICKINGTYPECREATERESPONSE._serialized_end = 10211
    _PICKINGTYPEREADREQUEST._serialized_start = 10214
    _PICKINGTYPEREADREQUEST._serialized_end = 10586
    _PICKINGTYPEREADRESPONSE._serialized_start = 10589
    _PICKINGTYPEREADRESPONSE._serialized_end = 10811
    _PICKINGTYPEUPDATEREQUEST._serialized_start = 10814
    _PICKINGTYPEUPDATEREQUEST._serialized_end = 10958
    _PICKINGTYPEUPDATERESPONSE._serialized_start = 10961
    _PICKINGTYPEUPDATERESPONSE._serialized_end = 11125
    _PICKINGTYPEDELETEREQUEST._serialized_start = 11127
    _PICKINGTYPEDELETEREQUEST._serialized_end = 11221
    _PICKINGTYPEDELETERESPONSE._serialized_start = 11223
    _PICKINGTYPEDELETERESPONSE._serialized_end = 11325
    _ROUTECREATEREQUEST._serialized_start = 11328
    _ROUTECREATEREQUEST._serialized_end = 11690
    _ROUTECREATERESPONSE._serialized_start = 11693
    _ROUTECREATERESPONSE._serialized_end = 11838
    _ROUTEREADREQUEST._serialized_start = 11841
    _ROUTEREADREQUEST._serialized_end = 12207
    _ROUTEREADRESPONSE._serialized_start = 12210
    _ROUTEREADRESPONSE._serialized_end = 12413
    _ROUTEUPDATEREQUEST._serialized_start = 12415
    _ROUTEUPDATEREQUEST._serialized_end = 12540
    _ROUTEUPDATERESPONSE._serialized_start = 12543
    _ROUTEUPDATERESPONSE._serialized_end = 12688
    _ROUTEDELETEREQUEST._serialized_start = 12690
    _ROUTEDELETEREQUEST._serialized_end = 12778
    _ROUTEDELETERESPONSE._serialized_start = 12780
    _ROUTEDELETERESPONSE._serialized_end = 12876
    _RULECREATEREQUEST._serialized_start = 12879
    _RULECREATEREQUEST._serialized_end = 13137
    _RULECREATERESPONSE._serialized_start = 13140
    _RULECREATERESPONSE._serialized_end = 13282
    _RULEREADREQUEST._serialized_start = 13285
    _RULEREADREQUEST._serialized_end = 13650
    _RULEREADRESPONSE._serialized_start = 13653
    _RULEREADRESPONSE._serialized_end = 13853
    _RULEUPDATEREQUEST._serialized_start = 13855
    _RULEUPDATEREQUEST._serialized_end = 13977
    _RULEUPDATERESPONSE._serialized_start = 13980
    _RULEUPDATERESPONSE._serialized_end = 14122
    _RULEDELETEREQUEST._serialized_start = 14124
    _RULEDELETEREQUEST._serialized_end = 14211
    _RULEDELETERESPONSE._serialized_start = 14213
    _RULEDELETERESPONSE._serialized_end = 14308
    _STOCKSERVICE._serialized_start = 14311
    _STOCKSERVICE._serialized_end = 18008
# @@protoc_insertion_point(module_scope)
