# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/users/user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13v1/users/user.proto\x12\x1epro.omni.oms.api.v1.users.user\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xc2\x03\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03sub\x18\x03 \x01(\t\x12\x0e\n\x06tenant\x18\x04 \x01(\t\x12\x10\n\x08username\x18\x05 \x01(\t\x12\r\n\x05\x65mail\x18\x06 \x01(\t\x12\x36\n\x08language\x18\x07 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Object\x12\x36\n\x08timezone\x18\x08 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Object\x12*\n\x06groups\x18\t \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x30\n\x0cis_superuser\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06\x61\x63tive\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\'\n\x03mfa\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\r \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xc8\x01\n\x05Group\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12*\n\x06\x61\x63\x63\x65ss\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xd7\x01\n\x06\x41\x63tion\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x14\n\x0cmicroservice\x18\x05 \x01(\t\x12\r\n\x05model\x18\x06 \x01(\t\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x08 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xf8\x01\n\x06\x41\x63\x63\x65ss\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0e\n\x06\x64omain\x18\x04 \x01(\t\x12\x11\n\taction_id\x18\x05 \x01(\t\x12\x36\n\x06\x61\x63tion\x18\x06 \x01(\x0b\x32&.pro.omni.oms.api.v1.users.user.Action\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x08 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x8f\x03\n\x11UserCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x15\n\remail_confirm\x18\x04 \x01(\t\x12\x10\n\x08password\x18\x05 \x01(\t\x12\x18\n\x10password_confirm\x18\x06 \x01(\t\x12.\n\ngroups_ids\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x30\n\x0cis_superuser\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x08language\x18\t \x01(\x0b\x32$.pro.omni.oms.api.common.base.Object\x12\x36\n\x08timezone\x18\n \x01(\x0b\x32$.pro.omni.oms.api.common.base.Object\x12\x36\n\x07\x63ontext\x18\x0b \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x93\x01\n\x12UserCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x32\n\x04user\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.v1.users.user.User"\xed\x02\n\x0fUserReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xcd\x01\n\x10UserReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x33\n\x05users\x18\x03 \x03(\x0b\x32$.pro.omni.oms.api.v1.users.user.User"\x7f\n\x11UserUpdateRequest\x12\x32\n\x04user\x18\x01 \x01(\x0b\x32$.pro.omni.oms.api.v1.users.user.User\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x93\x01\n\x12UserUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x32\n\x04user\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.v1.users.user.User"W\n\x11UserDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"_\n\x12UserDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8b\x01\n\x19UserChangePasswordRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x18\n\x10password_confirm\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"g\n\x1aUserChangePasswordResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x82\x01\n\x16UserChangeEmailRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x15\n\remail_confirm\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"d\n\x17UserChangeEmailResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x98\x01\n\x12GroupCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12.\n\naccess_ids\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x96\x01\n\x13GroupCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x34\n\x05group\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.v1.users.user.Group"\xee\x02\n\x10GroupReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd0\x01\n\x11GroupReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x35\n\x06groups\x18\x03 \x03(\x0b\x32%.pro.omni.oms.api.v1.users.user.Group"\x82\x01\n\x12GroupUpdateRequest\x12\x34\n\x05group\x18\x01 \x01(\x0b\x32%.pro.omni.oms.api.v1.users.user.Group\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x96\x01\n\x13GroupUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x34\n\x05group\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.v1.users.user.Group"X\n\x12GroupDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13GroupDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xa3\x01\n\x13\x41\x63tionCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0cmicroservice\x18\x04 \x01(\t\x12\r\n\x05model\x18\x05 \x01(\t\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x99\x01\n\x14\x41\x63tionCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x36\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.users.user.Action"\xef\x02\n\x11\x41\x63tionReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd3\x01\n\x12\x41\x63tionReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x37\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32&.pro.omni.oms.api.v1.users.user.Action"\x85\x01\n\x13\x41\x63tionUpdateRequest\x12\x36\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.users.user.Action\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x99\x01\n\x14\x41\x63tionUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x36\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.users.user.Action"Y\n\x13\x41\x63tionDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"a\n\x14\x41\x63tionDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8c\x01\n\x13\x41\x63\x63\x65ssCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0e\n\x06\x64omain\x18\x03 \x01(\t\x12\x11\n\taction_id\x18\x04 \x01(\t\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x99\x01\n\x14\x41\x63\x63\x65ssCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x36\n\x06\x61\x63\x63\x65ss\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.users.user.Access"\xef\x02\n\x11\x41\x63\x63\x65ssReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd4\x01\n\x12\x41\x63\x63\x65ssReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x38\n\x08\x61\x63\x63\x65sses\x18\x03 \x03(\x0b\x32&.pro.omni.oms.api.v1.users.user.Access"\x85\x01\n\x13\x41\x63\x63\x65ssUpdateRequest\x12\x36\n\x06\x61\x63\x63\x65ss\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.users.user.Access\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x99\x01\n\x14\x41\x63\x63\x65ssUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x36\n\x06\x61\x63\x63\x65ss\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.users.user.Access"Y\n\x13\x41\x63\x63\x65ssDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"a\n\x14\x41\x63\x63\x65ssDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"t\n\x14HasPermissionRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x12\n\npermission\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xae\x01\n\x15HasPermissionResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x16\n\x0ehas_permission\x18\x02 \x01(\x08\x12\x32\n\x04user\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.v1.users.user.User2\xb9\x12\n\x0cUsersService\x12u\n\nUserCreate\x12\x31.pro.omni.oms.api.v1.users.user.UserCreateRequest\x1a\x32.pro.omni.oms.api.v1.users.user.UserCreateResponse"\x00\x12o\n\x08UserRead\x12/.pro.omni.oms.api.v1.users.user.UserReadRequest\x1a\x30.pro.omni.oms.api.v1.users.user.UserReadResponse"\x00\x12u\n\nUserUpdate\x12\x31.pro.omni.oms.api.v1.users.user.UserUpdateRequest\x1a\x32.pro.omni.oms.api.v1.users.user.UserUpdateResponse"\x00\x12u\n\nUserDelete\x12\x31.pro.omni.oms.api.v1.users.user.UserDeleteRequest\x1a\x32.pro.omni.oms.api.v1.users.user.UserDeleteResponse"\x00\x12\x8d\x01\n\x12UserChangePassword\x12\x39.pro.omni.oms.api.v1.users.user.UserChangePasswordRequest\x1a:.pro.omni.oms.api.v1.users.user.UserChangePasswordResponse"\x00\x12\x84\x01\n\x0fUserChangeEmail\x12\x36.pro.omni.oms.api.v1.users.user.UserChangeEmailRequest\x1a\x37.pro.omni.oms.api.v1.users.user.UserChangeEmailResponse"\x00\x12x\n\x0bGroupCreate\x12\x32.pro.omni.oms.api.v1.users.user.GroupCreateRequest\x1a\x33.pro.omni.oms.api.v1.users.user.GroupCreateResponse"\x00\x12r\n\tGroupRead\x12\x30.pro.omni.oms.api.v1.users.user.GroupReadRequest\x1a\x31.pro.omni.oms.api.v1.users.user.GroupReadResponse"\x00\x12x\n\x0bGroupUpdate\x12\x32.pro.omni.oms.api.v1.users.user.GroupUpdateRequest\x1a\x33.pro.omni.oms.api.v1.users.user.GroupUpdateResponse"\x00\x12x\n\x0bGroupDelete\x12\x32.pro.omni.oms.api.v1.users.user.GroupDeleteRequest\x1a\x33.pro.omni.oms.api.v1.users.user.GroupDeleteResponse"\x00\x12{\n\x0c\x41\x63tionCreate\x12\x33.pro.omni.oms.api.v1.users.user.ActionCreateRequest\x1a\x34.pro.omni.oms.api.v1.users.user.ActionCreateResponse"\x00\x12u\n\nActionRead\x12\x31.pro.omni.oms.api.v1.users.user.ActionReadRequest\x1a\x32.pro.omni.oms.api.v1.users.user.ActionReadResponse"\x00\x12{\n\x0c\x41\x63tionUpdate\x12\x33.pro.omni.oms.api.v1.users.user.ActionUpdateRequest\x1a\x34.pro.omni.oms.api.v1.users.user.ActionUpdateResponse"\x00\x12{\n\x0c\x41\x63tionDelete\x12\x33.pro.omni.oms.api.v1.users.user.ActionDeleteRequest\x1a\x34.pro.omni.oms.api.v1.users.user.ActionDeleteResponse"\x00\x12{\n\x0c\x41\x63\x63\x65ssCreate\x12\x33.pro.omni.oms.api.v1.users.user.AccessCreateRequest\x1a\x34.pro.omni.oms.api.v1.users.user.AccessCreateResponse"\x00\x12u\n\nAccessRead\x12\x31.pro.omni.oms.api.v1.users.user.AccessReadRequest\x1a\x32.pro.omni.oms.api.v1.users.user.AccessReadResponse"\x00\x12{\n\x0c\x41\x63\x63\x65ssUpdate\x12\x33.pro.omni.oms.api.v1.users.user.AccessUpdateRequest\x1a\x34.pro.omni.oms.api.v1.users.user.AccessUpdateResponse"\x00\x12{\n\x0c\x41\x63\x63\x65ssDelete\x12\x33.pro.omni.oms.api.v1.users.user.AccessDeleteRequest\x1a\x34.pro.omni.oms.api.v1.users.user.AccessDeleteResponse"\x00\x12~\n\rHasPermission\x12\x34.pro.omni.oms.api.v1.users.user.HasPermissionRequest\x1a\x35.pro.omni.oms.api.v1.users.user.HasPermissionResponse"\x00\x62\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.users.user_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _USER._serialized_start = 137
    _USER._serialized_end = 587
    _GROUP._serialized_start = 590
    _GROUP._serialized_end = 790
    _ACTION._serialized_start = 793
    _ACTION._serialized_end = 1008
    _ACCESS._serialized_start = 1011
    _ACCESS._serialized_end = 1259
    _USERCREATEREQUEST._serialized_start = 1262
    _USERCREATEREQUEST._serialized_end = 1661
    _USERCREATERESPONSE._serialized_start = 1664
    _USERCREATERESPONSE._serialized_end = 1811
    _USERREADREQUEST._serialized_start = 1814
    _USERREADREQUEST._serialized_end = 2179
    _USERREADRESPONSE._serialized_start = 2182
    _USERREADRESPONSE._serialized_end = 2387
    _USERUPDATEREQUEST._serialized_start = 2389
    _USERUPDATEREQUEST._serialized_end = 2516
    _USERUPDATERESPONSE._serialized_start = 2519
    _USERUPDATERESPONSE._serialized_end = 2666
    _USERDELETEREQUEST._serialized_start = 2668
    _USERDELETEREQUEST._serialized_end = 2755
    _USERDELETERESPONSE._serialized_start = 2757
    _USERDELETERESPONSE._serialized_end = 2852
    _USERCHANGEPASSWORDREQUEST._serialized_start = 2855
    _USERCHANGEPASSWORDREQUEST._serialized_end = 2994
    _USERCHANGEPASSWORDRESPONSE._serialized_start = 2996
    _USERCHANGEPASSWORDRESPONSE._serialized_end = 3099
    _USERCHANGEEMAILREQUEST._serialized_start = 3102
    _USERCHANGEEMAILREQUEST._serialized_end = 3232
    _USERCHANGEEMAILRESPONSE._serialized_start = 3234
    _USERCHANGEEMAILRESPONSE._serialized_end = 3334
    _GROUPCREATEREQUEST._serialized_start = 3337
    _GROUPCREATEREQUEST._serialized_end = 3489
    _GROUPCREATERESPONSE._serialized_start = 3492
    _GROUPCREATERESPONSE._serialized_end = 3642
    _GROUPREADREQUEST._serialized_start = 3645
    _GROUPREADREQUEST._serialized_end = 4011
    _GROUPREADRESPONSE._serialized_start = 4014
    _GROUPREADRESPONSE._serialized_end = 4222
    _GROUPUPDATEREQUEST._serialized_start = 4225
    _GROUPUPDATEREQUEST._serialized_end = 4355
    _GROUPUPDATERESPONSE._serialized_start = 4358
    _GROUPUPDATERESPONSE._serialized_end = 4508
    _GROUPDELETEREQUEST._serialized_start = 4510
    _GROUPDELETEREQUEST._serialized_end = 4598
    _GROUPDELETERESPONSE._serialized_start = 4600
    _GROUPDELETERESPONSE._serialized_end = 4696
    _ACTIONCREATEREQUEST._serialized_start = 4699
    _ACTIONCREATEREQUEST._serialized_end = 4862
    _ACTIONCREATERESPONSE._serialized_start = 4865
    _ACTIONCREATERESPONSE._serialized_end = 5018
    _ACTIONREADREQUEST._serialized_start = 5021
    _ACTIONREADREQUEST._serialized_end = 5388
    _ACTIONREADRESPONSE._serialized_start = 5391
    _ACTIONREADRESPONSE._serialized_end = 5602
    _ACTIONUPDATEREQUEST._serialized_start = 5605
    _ACTIONUPDATEREQUEST._serialized_end = 5738
    _ACTIONUPDATERESPONSE._serialized_start = 5741
    _ACTIONUPDATERESPONSE._serialized_end = 5894
    _ACTIONDELETEREQUEST._serialized_start = 5896
    _ACTIONDELETEREQUEST._serialized_end = 5985
    _ACTIONDELETERESPONSE._serialized_start = 5987
    _ACTIONDELETERESPONSE._serialized_end = 6084
    _ACCESSCREATEREQUEST._serialized_start = 6087
    _ACCESSCREATEREQUEST._serialized_end = 6227
    _ACCESSCREATERESPONSE._serialized_start = 6230
    _ACCESSCREATERESPONSE._serialized_end = 6383
    _ACCESSREADREQUEST._serialized_start = 6386
    _ACCESSREADREQUEST._serialized_end = 6753
    _ACCESSREADRESPONSE._serialized_start = 6756
    _ACCESSREADRESPONSE._serialized_end = 6968
    _ACCESSUPDATEREQUEST._serialized_start = 6971
    _ACCESSUPDATEREQUEST._serialized_end = 7104
    _ACCESSUPDATERESPONSE._serialized_start = 7107
    _ACCESSUPDATERESPONSE._serialized_end = 7260
    _ACCESSDELETEREQUEST._serialized_start = 7262
    _ACCESSDELETEREQUEST._serialized_end = 7351
    _ACCESSDELETERESPONSE._serialized_start = 7353
    _ACCESSDELETERESPONSE._serialized_end = 7450
    _HASPERMISSIONREQUEST._serialized_start = 7452
    _HASPERMISSIONREQUEST._serialized_end = 7568
    _HASPERMISSIONRESPONSE._serialized_start = 7571
    _HASPERMISSIONRESPONSE._serialized_end = 7745
    _USERSSERVICE._serialized_start = 7748
    _USERSSERVICE._serialized_end = 10109
# @@protoc_insertion_point(module_scope)
